/***************************************************************
 * Name:      LEDwx01Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Niels Nikolaisen ()
 * Created:   2020-04-14
 * Copyright: Niels Nikolaisen ()
 * License:
 **************************************************************/

#include "LEDwx01Main.h"
#include <wx/msgdlg.h>
#include <wiringPi.h>

//(*InternalHeaders(LEDwx01Dialog)
#include <wx/font.h>
#include <wx/intl.h>
#include <wx/settings.h>
#include <wx/string.h>
//*)

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

//(*IdInit(LEDwx01Dialog)
const long LEDwx01Dialog::ID_STATICTEXT1 = wxNewId();
const long LEDwx01Dialog::ID_BUTTON1 = wxNewId();
const long LEDwx01Dialog::ID_BUTTON2 = wxNewId();
//*)

BEGIN_EVENT_TABLE(LEDwx01Dialog,wxDialog)
    //(*EventTable(LEDwx01Dialog)
    //*)
END_EVENT_TABLE()

LEDwx01Dialog::LEDwx01Dialog(wxWindow* parent,wxWindowID id)
{
    //(*Initialize(LEDwx01Dialog)
    Create(parent, wxID_ANY, _("LED Fun"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE, _T("wxID_ANY"));
    BoxSizer1 = new wxBoxSizer(wxHORIZONTAL);
    StaticText1 = new wxStaticText(this, ID_STATICTEXT1, _("LED Control"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT1"));
    wxFont StaticText1Font = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
    if ( !StaticText1Font.Ok() ) StaticText1Font = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
    StaticText1Font.SetPointSize(20);
    StaticText1->SetFont(StaticText1Font);
    BoxSizer1->Add(StaticText1, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 10);
    BoxSizer2 = new wxBoxSizer(wxVERTICAL);
    Button1 = new wxButton(this, ID_BUTTON1, _("LED an"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_BUTTON1"));
    BoxSizer2->Add(Button1, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
    Button2 = new wxButton(this, ID_BUTTON2, _("LED aus"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_BUTTON2"));
    BoxSizer2->Add(Button2, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
    BoxSizer1->Add(BoxSizer2, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 4);
    SetSizer(BoxSizer1);
    BoxSizer1->Fit(this);
    BoxSizer1->SetSizeHints(this);

    Connect(ID_BUTTON1,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&LEDwx01Dialog::OnButton1Click);
    Connect(ID_BUTTON2,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&LEDwx01Dialog::OnButton2Click);
    //*)

    wiringPiSetup();
    pinMode(5, OUTPUT);
    digitalWrite(5, LOW);
}

LEDwx01Dialog::~LEDwx01Dialog()
{
    //(*Destroy(LEDwx01Dialog)
    //*)
}

void LEDwx01Dialog::OnButton1Click(wxCommandEvent& event)
{
    digitalWrite(5, HIGH);
}

void LEDwx01Dialog::OnButton2Click(wxCommandEvent& event)
{
    digitalWrite(5, LOW);
}
